@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -27,12 +27,17 @@ class CategoryTypeComboBoxTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit CategoryTypeComboBoxTest(QObject *parent = Q_NULLPTR);
+    explicit CategoryTypeComboBoxTest(QObject *parent = nullptr);
     ~CategoryTypeComboBoxTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldSetType_data();
     void shouldSetType();
+
+    void shouldVerifyItNotDefault();
+    void shouldChangeDefaultCategory();
+
+    void shouldVerifyThatDefaultCategoryIsCorrect();
 };
 
 #endif // CATEGORYTYPECOMBOBOXTEST_H
